@@ -323,23 +323,20 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         return ret
 
     def get_only_get_distinct_field(self):
-        query_dc = self.get_request_data()
         key = 'only_get_distinct_field'
-        value = query_dc.get(key)
-        only_get_distinct_field = pure.convert_query_parameter_to_bool(value) if value else self.only_get_distinct_field
-        return only_get_distinct_field
+        value = self._get_key_from_query_dc_or_self(key)
+        ret = pure.convert_query_parameter_to_bool(value)
+        return ret
 
     def get_distinct_field_ls(self):
-        query_dc = self.get_request_data()
-        distinct_field_ls = get_list(query_dc, 'distinct_field_ls')
-        distinct_field_ls = distinct_field_ls if distinct_field_ls else self.distinct_field_ls
-        return distinct_field_ls
+        key = 'distinct_field_ls'
+        ret = self._get_key_from_query_dc_or_self(key)
+        return ret
 
     def get_base_fields(self):
-        query_dc = self.get_request_data()
-        base_fields = get_list(query_dc, 'base_fields')
-        base_fields = base_fields if base_fields else self.base_fields
-        return base_fields
+        key = 'base_fields'
+        ret = self._get_key_from_query_dc_or_self(key)
+        return ret
 
     def get_retrieve_ret(self, request: Request, *args, **kwargs):
         """
@@ -557,6 +554,14 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         }
         return ret
 
+    def _get_key_from_query_dc_or_self(self, key):
+        query_dc = self.get_request_data()
+        data = query_dc.get(key)
+
+        ret = data if data else None
+        ret = getattr(self, key) if hasattr(self, key) else None
+        return ret
+
 
 class BaseList(BaseListView):     # 向下兼容, 返回格式调整, 重写_conv_data_format.
     def _conv_data_format(self, data: (dict, Response)):
